KeyName class
class to hold key names
keynames are readable string constants for keys
Constructors
- KeyName()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
names
→ Map<
LogicalKeyboardKey, String> -
final
Static Methods
-
areKeysEqual(
List< LogicalKeyboardKey> a, List<LogicalKeyboardKey> b) → dynamic -
forKey(
LogicalKeyboardKey key) → String -
forKeys(
List< LogicalKeyboardKey> keys) → String -
isKeyEqual(
LogicalKeyboardKey a, LogicalKeyboardKey b) → bool -
normalisedKeyName(
LogicalKeyboardKey key) → String