KeyCombo class

Constructors

KeyCombo({List<LogicalKeyboardKey> modifiers = const [], required Map<LogicalKeyboardKey, KeyCallback> bindings})

Properties

bindings Map<LogicalKeyboardKey, KeyCallback>
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
Returns a unique identifier string for this combo based on its modifiers Used for mapping and lookup
no setter
modifiers List<LogicalKeyboardKey>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(LogicalKeyboardKey triggeredKey) → void
Handle the key event by invoking the appropriate callback triggeredKey is the key that was just pressed (non-modifier key)
hasBindingFor(LogicalKeyboardKey key) bool
Check if this combo has a binding for the given key
matches(Set<LogicalKeyboardKey> pressed) bool
Check if the combo is active based on currently pressed modifiers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited