hasBindingFor method
Check if this combo has a binding for the given key
Implementation
bool hasBindingFor(LogicalKeyboardKey key) {
return bindings.containsKey(key);
}
Check if this combo has a binding for the given key
bool hasBindingFor(LogicalKeyboardKey key) {
return bindings.containsKey(key);
}