KeyMaps class

Constructors

KeyMaps({required List<KeyCombo> combos})

Properties

combos List<KeyCombo>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleKeyEvent(KeyEvent e) → void
isAlreadyPressed(LogicalKeyboardKey k) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited