identifier property
String
get
identifier
Returns a unique identifier string for this combo based on its modifiers Used for mapping and lookup
Implementation
String get identifier {
return KeyName.forKeys(modifiers);
}